==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/core-impl/collections/db/sql/mysqlcollection/MySqlQueryMaker.h <==
/****************************************************************************************
 * Copyright (c) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_COLLECTION_MYSQLQUERYMAKER_H
#define AMAROK_COLLECTION_MYSQLQUERYMAKER_H

#include "../SqlCollection.h"
#include "../SqlQueryMaker.h"

namespace Collections
{

class MySqlQueryMaker : public SqlQueryMaker
{
    public:
        MySqlQueryMaker( SqlCollection* collection );
        virtual ~MySqlQueryMaker();

    protected:
        virtual QString escape( QString text ) const;
};

}

#endif

==> amarok_3.3.2.orig.tar.xz: amarok-3.3.2/src/core-impl/collections/db/sql/mysqlcollection/MySqlQueryMaker.h <==
/****************************************************************************************
 * Copyright (c) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_COLLECTION_MYSQLQUERYMAKER_H
#define AMAROK_COLLECTION_MYSQLQUERYMAKER_H

#include "../SqlCollection.h"
#include "../SqlQueryMaker.h"

namespace Collections
{

class MySqlQueryMaker : public SqlQueryMaker
{
    public:
        explicit MySqlQueryMaker( SqlCollection* collection );
        ~MySqlQueryMaker() override;

    protected:
        QString escape( const QString &text ) const override;
};

}

#endif
